==> haskell-dense-linear-algebra-0.1.0.0-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dense-linear-algebra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dense-linear-algebra
version: 0.1.0.0
id: dense-linear-algebra-0.1.0.0-4qTE3dWNpYwKc6ndKBAXth
key: dense-linear-algebra-0.1.0.0-4qTE3dWNpYwKc6ndKBAXth
license: BSD-2-Clause
copyright: 2018 Author name here
maintainer: Alexey Khudaykov <alexey.skladnoy@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
synopsis: Simple and incomplete pure haskell implementation of linear algebra
description:
    This library is simply collection of linear-algebra related modules
    split from statistics library.
category: Math, Statistics, Numeric
abi: 9cf81e2fb0739ad74d7eb008a85ccc8e
exposed: True
exposed-modules:
    Statistics.Matrix Statistics.Matrix.Algorithms
    Statistics.Matrix.Function Statistics.Matrix.Mutable
    Statistics.Matrix.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/dense-linear-algebra-0.1.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/dense-linear-algebra-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/dense-linear-algebra-0.1.0.0
hs-libraries: HSdense-linear-algebra-0.1.0.0-4qTE3dWNpYwKc6ndKBAXth
depends:
    base-4.12.0.0 deepseq-1.4.4.0
    math-functions-0.3.1.0-GW8vg3sPECY78WvUCbZJWc
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vector-algorithms-0.8.0.1-4s0mIQGU3s1C8KiZioXwL7
    vector-binary-instances-0.2.5.1-Dz95yg9LO4QICxc7gaTUaF
    vector-th-unbox-0.2.1.6-LZLuOhl72IF7NW8IrRJm9b
haddock-interfaces: /usr/share/doc/haskell-dense-linear-algebra/html/dense-linear-algebra.haddock
haddock-html: /usr/share/doc/haskell-dense-linear-algebra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dense-linear-algebra-0.1.0.0-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dense-linear-algebra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dense-linear-algebra
version: 0.1.0.0
id: dense-linear-algebra-0.1.0.0-4Ey7CX6VKGc5Xv2s9dCXKJ
key: dense-linear-algebra-0.1.0.0-4Ey7CX6VKGc5Xv2s9dCXKJ
license: BSD-2-Clause
copyright: 2018 Author name here
maintainer: Alexey Khudaykov <alexey.skladnoy@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
synopsis: Simple and incomplete pure haskell implementation of linear algebra
description:
    This library is simply collection of linear-algebra related modules
    split from statistics library.
category: Math, Statistics, Numeric
abi: c687667fafb0eefa36c2b1ef174d34a0
exposed: True
exposed-modules:
    Statistics.Matrix Statistics.Matrix.Algorithms
    Statistics.Matrix.Function Statistics.Matrix.Mutable
    Statistics.Matrix.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/dense-linear-algebra-0.1.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/dense-linear-algebra-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/dense-linear-algebra-0.1.0.0
hs-libraries: HSdense-linear-algebra-0.1.0.0-4Ey7CX6VKGc5Xv2s9dCXKJ
depends:
    base-4.12.0.0 deepseq-1.4.4.0
    math-functions-0.3.1.0-GW8vg3sPECY78WvUCbZJWc
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vector-algorithms-0.8.0.1-4s0mIQGU3s1C8KiZioXwL7
    vector-binary-instances-0.2.5.1-Dz95yg9LO4QICxc7gaTUaF
    vector-th-unbox-0.2.1.6-LZLuOhl72IF7NW8IrRJm9b
haddock-interfaces: /usr/share/doc/haskell-dense-linear-algebra/html/dense-linear-algebra.haddock
haddock-html: /usr/share/doc/haskell-dense-linear-algebra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
